﻿using System;
using System.Data;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;
using PdfSharp;
using PdfSharp.Pdf;
using System.Collections.ObjectModel;
using System.Diagnostics;

namespace AdornmentInteractiveOverlaySample
{
    public partial class MainForm : Form
    {
        private Timer timer = new Timer();

        public MainForm()
        {
            InitializeComponent();
        }

        private void MainForm_Load(object sender, EventArgs e)
        {
            InitMap();

            // Compass            
            LoadCompass(true);

            // Label
            LoadLabel(true);
            timer.Interval = 1000;
            timer.Tick += new EventHandler(timer_Tick);
            winformsMap1.Refresh();
        }

        int timerIndex = 0;
        void timer_Tick(object sender, EventArgs e)
        {
            AdornmentInteractiveOverlay adornmentInteractiveOverlay = (AdornmentInteractiveOverlay)winformsMap1.InteractiveOverlays["AdornmentInteractiveOverlay"];
            //if (!adornmentInteractiveOverlay.EditingDisabled)
            {
                adornmentInteractiveOverlay.AdornmentLayers.Clear();
                timerIndex++;

                GeoImage needleImage = new GeoImage(@"..\..\Images\Compass.png");
                CompassAdornmentLayer compassAdornmentLayer = new CompassAdornmentLayer(needleImage);
                compassAdornmentLayer.Location = AdornmentLocation.UseOffsets;
                compassAdornmentLayer.XOffsetInPixel = 300 + timerIndex * 10;
                compassAdornmentLayer.YOffsetInPixel = 500 + timerIndex * 10;

                compassAdornmentLayer.Width = 71;
                compassAdornmentLayer.Height = 69;
                adornmentInteractiveOverlay.AdornmentLayers.Add(compassAdornmentLayer);

                LabelAdornmentLayer LabelAdornmentLayer = new LabelAdornmentLayer("World Map \n sfsfsfs", new GeoFont("Arial", 10), 200, 20, GeoColor.StandardColors.Blue);
                LabelAdornmentLayer.Location = AdornmentLocation.UseOffsets;
                LabelAdornmentLayer.XOffsetInPixel = 210 + timerIndex * 10;
                LabelAdornmentLayer.YOffsetInPixel = 190 + timerIndex * 10;
                adornmentInteractiveOverlay.AdornmentLayers.Add(LabelAdornmentLayer);

                winformsMap1.Refresh();
            }
        }

        private void InitMap()
        {
            winformsMap1.MapUnit = GeographyUnit.Meter;
            winformsMap1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.StandardColors.LightGray);

            AdornmentInteractiveOverlay adornmentInteractiveOverlay = new AdornmentInteractiveOverlay();
            winformsMap1.InteractiveOverlays.Add("AdornmentInteractiveOverlay", adornmentInteractiveOverlay);
            winformsMap1.InteractiveOverlays.MoveToBottom("AdornmentInteractiveOverlay");
            adornmentInteractiveOverlay.EditingDisabled = true;
        }

        private void LoadCompass(bool addToMap)
        {
            if (!addToMap)
            {
                return;
            }

            GeoImage needleImage = new GeoImage(@"..\..\Images\Compass.png");
            CompassAdornmentLayer compassAdornmentLayer = new CompassAdornmentLayer(needleImage);
            compassAdornmentLayer.Location = AdornmentLocation.UseOffsets;
            compassAdornmentLayer.XOffsetInPixel = 300;
            compassAdornmentLayer.YOffsetInPixel = 500;
            compassAdornmentLayer.Width = 71;
            compassAdornmentLayer.Height = 69;
            AdornmentInteractiveOverlay adornmentInteractiveOverlay = (AdornmentInteractiveOverlay)winformsMap1.InteractiveOverlays["AdornmentInteractiveOverlay"];
            adornmentInteractiveOverlay.AdornmentLayers.Add(compassAdornmentLayer);
        }

        private void LoadLabel(bool addToMap)
        {
            if (!addToMap)
            {
                return;
            }

            LabelAdornmentLayer LabelAdornmentLayer = new LabelAdornmentLayer("World Map \n sfsfsfs", new GeoFont("Arial", 10), 200, 20, GeoColor.StandardColors.Blue);
            LabelAdornmentLayer.Location = AdornmentLocation.UseOffsets;
            LabelAdornmentLayer.XOffsetInPixel = 210;
            LabelAdornmentLayer.YOffsetInPixel = 190;
            AdornmentInteractiveOverlay adornmentInteractiveOverlay = (AdornmentInteractiveOverlay)winformsMap1.InteractiveOverlays["AdornmentInteractiveOverlay"];
            adornmentInteractiveOverlay.AdornmentLayers.Add(LabelAdornmentLayer);
        }

        private void disableEditingCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            AdornmentInteractiveOverlay adornmentInteractiveOverlay = (AdornmentInteractiveOverlay)winformsMap1.InteractiveOverlays["AdornmentInteractiveOverlay"];
            if (disableEditingCheckBox.Checked)
            {
                adornmentInteractiveOverlay.EditingDisabled = true;
            }
            else
            {
                adornmentInteractiveOverlay.EditingDisabled = false;
            }
            winformsMap1.Refresh();
        }

        private void chkMoveTimer_CheckedChanged(object sender, EventArgs e)
        {
            if (chkMoveTimer.Checked)
            {
                timer.Stop();
            }
            else
            {
                timer.Start();
            }
        }

    }
}
